@@ -41,119 +41,6 @@
 
 #include "media_user_setting_specific.h"
 #include "null_hardware.h"
-extern PerfUtility *g_perfutility;
-
-#define PERF_DECODE "DECODE"
-#define PERF_ENCODE "ENCODE"
-#define PERF_VP "VP"
-#define PERF_CP "CP"
-#define PERF_MOS "MOS"
-
-#define PERF_LEVEL_DDI "DDI"
-#define PERF_LEVEL_HAL "HAL"
-
-#define DECODE_DDI (1)
-#define DECODE_HAL (1 << 1)
-#define ENCODE_DDI (1 << 4)
-#define ENCODE_HAL (1 << 5)
-#define VP_DDI     (1 << 8)
-#define VP_HAL     (1 << 9)
-#define CP_DDI     (1 << 12)
-#define CP_HAL     (1 << 13)
-#define MOS_DDI    (1 << 16)
-#define MOS_HAL    (1 << 17)
-
-#define PERFUTILITY_IS_ENABLED(sCOMP,sLEVEL)                                                              \
-    (((sCOMP == "DECODE" && sLEVEL == "DDI") && (g_perfutility->dwPerfUtilityIsEnabled & DECODE_DDI)) ||  \
-     ((sCOMP == "DECODE" && sLEVEL == "HAL") && (g_perfutility->dwPerfUtilityIsEnabled & DECODE_HAL)) ||  \
-     ((sCOMP == "ENCODE" && sLEVEL == "DDI") && (g_perfutility->dwPerfUtilityIsEnabled & ENCODE_DDI)) ||  \
-     ((sCOMP == "ENCODE" && sLEVEL == "HAL") && (g_perfutility->dwPerfUtilityIsEnabled & ENCODE_HAL)) ||  \
-     ((sCOMP == "VP" && sLEVEL == "DDI") && (g_perfutility->dwPerfUtilityIsEnabled & VP_DDI)) ||          \
-     ((sCOMP == "VP" && sLEVEL == "HAL") && (g_perfutility->dwPerfUtilityIsEnabled & VP_HAL)) ||          \
-     ((sCOMP == "CP" && sLEVEL == "DDI") && (g_perfutility->dwPerfUtilityIsEnabled & CP_DDI)) ||          \
-     ((sCOMP == "CP" && sLEVEL == "HAL") && (g_perfutility->dwPerfUtilityIsEnabled & CP_HAL)) ||          \
-     ((sCOMP == "MOS" && sLEVEL == "DDI") && (g_perfutility->dwPerfUtilityIsEnabled & MOS_DDI)) ||        \
-     ((sCOMP == "MOS" && sLEVEL == "HAL") && (g_perfutility->dwPerfUtilityIsEnabled & MOS_HAL)))
-
-#define PERF_UTILITY_START(TAG,COMP,LEVEL)                                 \
-    do                                                                     \
-    {                                                                      \
-        if (PERFUTILITY_IS_ENABLED((std::string)COMP,(std::string)LEVEL))  \
-        {                                                                  \
-            g_perfutility->startTick(TAG);                                 \
-        }                                                                  \
-    } while(0)
-
-#define PERF_UTILITY_STOP(TAG, COMP, LEVEL)                                \
-    do                                                                     \
-    {                                                                      \
-        if (PERFUTILITY_IS_ENABLED((std::string)COMP,(std::string)LEVEL))  \
-        {                                                                  \
-            g_perfutility->stopTick(TAG);                                  \
-        }                                                                  \
-    } while (0)
-
-static int perf_count_start = 0;
-static int perf_count_stop = 0;
-
-#define PERF_UTILITY_START_ONCE(TAG, COMP,LEVEL)                           \
-    do                                                                     \
-    {                                                                      \
-        if (perf_count_start == 0                                          \
-            && PERFUTILITY_IS_ENABLED((std::string)COMP,(std::string)LEVEL))  \
-        {                                                                  \
-                g_perfutility->startTick(TAG);                             \
-        }                                                                  \
-        perf_count_start++;                                                \
-    } while(0)
-
-#define PERF_UTILITY_STOP_ONCE(TAG, COMP, LEVEL)                           \
-    do                                                                     \
-    {                                                                      \
-        if (perf_count_stop == 0                                           \
-            && PERFUTILITY_IS_ENABLED((std::string)COMP,(std::string)LEVEL))  \
-        {                                                                  \
-            g_perfutility->stopTick(TAG);                                  \
-        }                                                                  \
-        perf_count_stop++;                                                 \
-    } while (0)
-
-#define PERF_UTILITY_AUTO(TAG,COMP,LEVEL) AutoPerfUtility apu(TAG,COMP,LEVEL)
-
-#define PERF_UTILITY_PRINT                         \
-    do                                             \
-    {                                              \
-        if (g_perfutility->dwPerfUtilityIsEnabled && MosUtilities::MosIsProfilerDumpEnabled()) \
-        {                                          \
-            g_perfutility->savePerfData();         \
-        }                                          \
-    } while(0)
-
-class AutoPerfUtility
-{
-public:
-    AutoPerfUtility(std::string tag, std::string comp, std::string level)
-    {
-        if (PERFUTILITY_IS_ENABLED(comp, level))
-        {
-            g_perfutility->startTick(tag);
-            autotag = tag;
-            bEnable = true;
-        }
-    }
-    ~AutoPerfUtility()
-    {
-        if (bEnable)
-        {
-            g_perfutility->stopTick(autotag);
-        }
-    }
-
-private:
-    bool bEnable = false;
-    std::string autotag ="intialized";
-};
-
 //!
 //! \brief OS specific includes and definitions
 //!
@@ -255,6 +142,13 @@ typedef enum _MOS_SCALABILITY_ENABLE_MODE
     MOS_SCALABILITY_ENABLE_MODE_USER_FORCE = 0x0010
 } MOS_SCALABILITY_ENABLE_MODE;
 
+typedef enum _TRINITY_PATH
+{
+    TRINITY_DISABLED  = 0,
+    TRINITY9_ENABLED  = 1,
+    TRINITY11_ENABLED = 2,
+} TRINITY_PATH;
+
 #if (_DEBUG || _RELEASE_INTERNAL)
 //!
 //! \brief for forcing VDBOX
@@ -641,7 +535,7 @@ struct MosStreamState
     int32_t eForceVebox                         = 0;        //!< Force select Vebox
 #endif // _DEBUG || _RELEASE_INTERNAL
 
-    bool  bGucSubmission                        = false;    //!< Flag to indicate if guc submission is enabled
+    bool  bParallelSubmission                        = false;    //!< Flag to indicate if parallel submission is enabled
     OS_PER_STREAM_PARAMETERS  perStreamParameters = nullptr; //!< Parameters of OS specific per stream
 
     static void *pvSoloContext;                             //!< pointer to MediaSolo context
@@ -685,6 +579,28 @@ class CodechalSetting;
 class CodechalHwInterface;
 class CodechalHwInterfaceNext;
 
+struct MOS_SURF_DUMP_SURFACE_DEF
+{
+    uint32_t offset;  //!< Offset from start of the plane
+    uint32_t height;  //!< Height in rows
+    uint32_t width;   //!< Width in bytes
+    uint32_t pitch;   //!< Pitch in bytes
+};
+
+struct ResourceDumpAttri
+{
+    MOS_RESOURCE            res           = {};
+    MOS_LOCK_PARAMS         lockFlags     = {};
+    std::string             fullFileName  = {};
+    uint32_t                width         = 0;
+    uint32_t                height        = 0;
+    uint32_t                pitch         = 0;
+    MOS_GFXRES_FREE_FLAGS   resFreeFlags  = {};
+    MOS_PLANE_OFFSET        yPlaneOffset  = {};  // Y surface plane offset
+    MOS_PLANE_OFFSET        uPlaneOffset  = {};  // U surface plane offset
+    MOS_PLANE_OFFSET        vPlaneOffset  = {};  // V surface plane offset
+};
+
 //!
 //! \brief Structure to Unified HAL OS resources
 //!
@@ -757,6 +673,7 @@ typedef struct _MOS_INTERFACE
     // used for media reset enabling/disabling in UMD
     // pls remove it after hw scheduling
     int32_t                         bMediaReset;
+    TRINITY_PATH                    trinityPath;
 
     bool                            umdMediaResetEnable;
 
@@ -793,6 +710,7 @@ typedef struct _MOS_INTERFACE
 #endif // (_DEBUG || _RELEASE_INTERNAL)
 
     bool                            apoMosEnabled;                                //!< apo mos or not
+    std::vector<ResourceDumpAttri>  resourceDumpAttriArray;
 
     MEMORY_OBJECT_CONTROL_STATE (* pfnCachePolicyGetMemoryObject) (
         MOS_HW_RESOURCE_DEF         Usage,
@@ -1309,6 +1227,18 @@ typedef struct _MOS_INTERFACE
     bool (*pfnIsMultipleCodecDevicesInUse)(
         PMOS_INTERFACE              pOsInterface);
 
+    MOS_STATUS (*pfnSetMultiEngineEnabled)(
+        PMOS_INTERFACE pOsInterface,
+        MOS_COMPONENT  component,
+        bool           enabled);
+
+    MOS_STATUS (*pfnGetMultiEngineStatus)(
+        PMOS_INTERFACE pOsInterface,
+        PLATFORM      *platform,
+        MOS_COMPONENT  component,
+        bool          &isMultiDevices,
+        bool          &isMultiEngine);
+
     MOS_GPU_NODE(*pfnGetLatestVirtualNode)(
         PMOS_INTERFACE              pOsInterface,
         MOS_COMPONENT               component);
@@ -1604,7 +1534,7 @@ typedef struct _MOS_INTERFACE
     //! \return   void
     //!
     void (*pfnGetRtLogResourceInfo)(
-        MOS_STREAM_HANDLE           streamState,
+        PMOS_INTERFACE              osInterface,
         PMOS_RESOURCE               &osResource,
         uint32_t                    &size);
 
@@ -1648,6 +1578,20 @@ typedef struct _MOS_INTERFACE
     uint8_t (*pfnGetEngineLogicIdByIdx)(
         MOS_STREAM_HANDLE           streamState,
         uint32_t                    instanceIdx);
+
+    //!
+    //! \brief    Set Gpu Virtual Address for Debug
+    //! \details  Manually make page fault
+    //!
+    //! \param    [in] pResource
+    //!           Resource to set Gpu Address
+    //! \param    [in] address
+    //!           Address to set
+    //! \return   MOS_STATUS
+    //!
+    MOS_STATUS (*pfnSetGpuVirtualAddress)(
+        PMOS_RESOURCE               pResource,
+        uint64_t                    address);
 #endif
 
 #if MOS_MEDIASOLO_SUPPORTED
@@ -2036,6 +1980,19 @@ typedef struct _MOS_INTERFACE
         PMOS_INTERFACE                 pOsInterface,
         uint8_t&                       id);
 #endif
+    //!
+    //! \brief    Is Device Async or not
+    //! \details  Is Device Async or not.
+    //!
+    //! \param    PMOS_INTERFACE pOsInterface
+    //!           [in] OS Interface
+    //!
+    //! \return   bool
+    //!           Return true if is async, otherwise false
+    //!
+    bool (*pfnIsAsynDevice)(
+        PMOS_INTERFACE              osInterface);
+
     //!
     //! \brief   Get User Setting instance
     //!
@@ -2056,7 +2013,7 @@ typedef struct _MOS_INTERFACE
     bool                            phasedSubmission = false;                     //!< Flag to indicate if secondary command buffers are submitted together (Win) or separately (Linux)
     bool                            frameSplit = true;                            //!< Flag to indicate if frame split is enabled
     bool                            bSetHandleInvalid = false;
-    bool                            bGucSubmission = false;                       //!< Flag to indicate if guc submission is enabled
+    bool                            bParallelSubmission = false;                       //!< Flag to indicate if parallel submission is enabled
     MOS_CMD_BUF_ATTRI_VE            bufAttriVe[MOS_GPU_CONTEXT_MAX];
 
     MOS_STATUS (*pfnCheckVirtualEngineSupported)(
@@ -2451,7 +2408,7 @@ uint64_t Mos_GetResourceHandle(
 //! \return   void
 //!
 void Mos_GetRtLogResourceInfo(
-    MOS_STREAM_HANDLE       streamState,
+    PMOS_INTERFACE          osInterface,
     PMOS_RESOURCE           &osResource,
     uint32_t                &size);
 
@@ -2496,6 +2453,20 @@ uint8_t Mos_GetEngineLogicId(
     MOS_STREAM_HANDLE       streamState,
     uint32_t                instanceIdx);
 
+//!
+//! \brief    Set Gpu Virtual Address for Debug
+//! \details  Manually make page fault
+//!
+//! \param    [in] pResource
+//!           Resource to set Gpu Address
+//! \param    [in] address
+//!           Address to set
+//! \return   MOS_STATUS
+//!
+MOS_STATUS MOS_SetGpuVirtualAddress(
+    PMOS_RESOURCE pResource, 
+    uint64_t      address);
+
 #endif
 
 struct ContextRequirement
