@@ -682,6 +682,7 @@ typedef enum _MT_LOG_ID
     MT_CP_DDI_RESOURCE_CREATE,
     MT_CP_DDI_OS_RESOURCE_INIT,
     MT_CP_DDI_FUNC_UNSUPPORTED,
+    MT_CP_DDI_LBDM_FALLBACK_SWDRM,
     MT_LOG_ID_VP_BASE = 0x02000000,
     MT_VP_CREATE,
     MT_VP_DESTROY,
@@ -743,6 +744,7 @@ typedef enum _MT_LOG_ID
     MT_VP_FEATURE_GRAPH_INPUT_SURFACE_INFO,
     MT_VP_FEATURE_GRAPH_INTERMEIDATE_SURFACE_INFO,
     MT_VP_FEATURE_GRAPH_OUTPUT_SURFACE_INFO,
+    MT_VP_FEATURE_GRAPH_SURFACE_ALLOCATIONHANDLE,
     MT_VP_HAL_ID_BASE = 0x02000400,
     MT_VP_HAL_PIPELINE_ADAPTER,
     MT_VP_HAL_PIPELINE_ADAPTER_EXT_ENTRY,
@@ -865,6 +867,7 @@ typedef enum _MT_PARAM_ID
     MT_FUNC_LINE,
     MT_MEMORY_PTR,
     MT_MEMORY_SIZE,
+    MT_MEMORY_INDEX,
     MT_PARAM_ID_MOS_BASE = 0x00001000,
     MT_MOS_STATUS,
     MT_MOS_GPU_NODE,
