@@ -282,10 +282,7 @@ namespace encode
         if (m_pipeline->GetPipeNum() >= 2)
         {
             auto scalability = m_pipeline->GetMediaScalability();
-            if (m_pipeline->IsFirstPass())
-            {
-                ENCODE_CHK_STATUS_RETURN(scalability->ResetSemaphore(syncOnePipeWaitOthers, 0, &cmdBuffer));
-            }
+
             ENCODE_CHK_STATUS_RETURN(scalability->SyncPipe(syncOtherPipesForOne, 0, &cmdBuffer));
         }
 
@@ -459,7 +456,7 @@ namespace encode
         // End patching tile level batch cmds
         RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, EndPatchTileLevelBatch);
 
-        if (tileRowPass != 1)
+        if (tileRowPass != 1) // for dummy tile, donnot calculate tile size into frame size.
         {
             if (m_pipeline->GetPipeNum() > 1)
             {
@@ -577,6 +574,10 @@ namespace encode
 
         if (m_pipeline->IsFirstPipe()) 
         {
+            for (auto i = 0; i < m_pipeline->GetPipeNum(); ++i)
+            {
+                ENCODE_CHK_STATUS_RETURN(scalability->ResetSemaphore(syncOnePipeWaitOthers, i, &cmdBuffer));
+            }
             ENCODE_CHK_STATUS_RETURN(EndStatusReport(statusReportMfx, &cmdBuffer));
         }
         else{
