@@ -1990,7 +1990,7 @@ VAStatus MediaLibvaUtilNext::GetSurfaceModifier(
             modifier = I915_FORMAT_MOD_X_TILED;
             break;
         case GMM_NOT_TILED:
-            modifier = DRM_FORMAT_MOD_NONE;
+            modifier = DRM_FORMAT_MOD_LINEAR;
             break;
         default:
             //handle other possible tile format
@@ -2001,7 +2001,7 @@ VAStatus MediaLibvaUtilNext::GetSurfaceModifier(
             }
             else
             {
-                modifier = DRM_FORMAT_MOD_NONE;
+                modifier = DRM_FORMAT_MOD_LINEAR;
             }
             break;
 
